Function sp_io::logging::max_level [−][src]
pub fn max_level() -> LogLevelFilterExpand description
Returns the max log level used by the host.
pub fn max_level() -> LogLevelFilterReturns the max log level used by the host.